=======
History
=======

0.1.6 (2018-09-18)
------------------

* Added ability to output reconciliation report to 'zip' or 'xlsx'
* Added reconciliation stats for quick reference

0.1.5 (2018-09-17)
------------------

* First release on PyPI.
* ability to output reconciliations within console or in a jupyter notebook

